@@ -8,7 +8,7 @@ package Net::FattureInCloud {
     use version;
     use v5.36;
 
-    our $VERSION = qv("v0.2.0");
+    our $VERSION = qv("v0.2.1");
 
     has endpoint_uri => ( is => 'ro', default => sub { 'https://api-v2.fattureincloud.it/' } );
     has token => ( is => 'ro' );
@@ -31,7 +31,7 @@ package Net::FattureInCloud {
             %$args,
         };
 
-        my $datatransport = $method eq 'GET' ? 'form' : 'json';
+        my $datatransport = $method eq 'get' ? 'form' : 'json';
 
         my $res = $self->ua->$method( $self->endpoint_uri . "$path" =>
             { Authorization => 'Bearer ' . $self->token },
@@ -51,7 +51,7 @@ package Net::FattureInCloud {
             %$args,
         };
 
-        my $datatransport = $method eq 'GET' ? 'form' : 'json';
+        my $datatransport = $method eq 'get' ? 'form' : 'json';
 
         my $res = $self->ua->$method( $self->endpoint_uri . 'c/' . $self->company_id . "/$path" =>
             { Authorization => 'Bearer ' . $self->token },
